#include "../include/Queue.h"
#include <algorithm>

namespace Queue {
std::deque<std::string> queue;
std::string curTransfer = "";
std::mutex mtx;
ChannelControls *channel;
} // namespace Queue

bool Queue::push(const std::string &file) {
	// Don't queue if no channel is available
	if (channel == nullptr) {
		return false;
	}

	mtx.lock();
	queue.push_back(file);
	mtx.unlock();

	// TODO run in extra thread??
	if (curTransfer.compare("") == 0) {
		schedule();
	}

	return true;
}

bool Queue::remove(const std::string &file) {
	if (curTransfer.compare(file) == 0) {
		// TODO check if remove is allowed
		return false;
	} else {
		mtx.lock();
		auto it = std::find(queue.begin(), queue.end(), file);
		if (it == queue.end()) {
			return false;
		}
		queue.erase(it);
		mtx.unlock();
		return true;
	}
}

void Queue::schedule() {
	if (!queue.empty()) {
		mtx.lock();
		std::string file = queue.front();
		queue.pop_front();
		curTransfer = file;

		// success is false if file could not be sent or found
		bool success = channel->sendFile(curTransfer);
		mtx.unlock();

		if (!success) {
			schedule();
		}

		// don't wait until transer finished because schedule must be called again
	} else {
		mtx.lock();
		curTransfer = "";
		mtx.unlock();
	}
}
